import React, { useMemo } from 'react';
import TreeFileIcon from './FileIcon';
import { useTreeContext } from './TreeContext';
import TreeIndents from './TreeIndents';
import { makeChildPath, stopPropagation } from '../helpers';
import { buildClassName } from '../presets';
const defaultProps = {
    level: 0,
    className: '',
    parentPath: '',
};
const TreeFile = ({ name, parentPath, level, extra, className, parentExpanded, ...props }) => {
    const { onFileClick } = useTreeContext();
    const currentPath = useMemo(() => makeChildPath(name, parentPath), []);
    const clickHandler = (event) => {
        stopPropagation(event);
        onFileClick && onFileClick(currentPath);
    };
    return (<div className={buildClassName('file')} onClick={clickHandler} {...props}>
      <div className={buildClassName('file-names')} style={{
            marginLeft: `calc(1.875rem * ${level})`,
        }}>
        <TreeIndents count={level}/>
        <span className={buildClassName('file-icon')}>
          <TreeFileIcon />
        </span>
        <span className={buildClassName('file-name')}>
          {name}
          {extra && (<span className={buildClassName('file-extra')}>{extra}</span>)}
        </span>
      </div>
    </div>);
};
TreeFile.defaultProps = defaultProps;
TreeFile.displayName = 'GeistTreeFile';
export default TreeFile;
