import React from 'react';
export const sortChildren = (children, folderComponentType) => {
    return React.Children.toArray(children).sort((a, b) => {
        if (!React.isValidElement(a) || !React.isValidElement(b))
            return 0;
        if (a.type !== b.type)
            return a.type !== folderComponentType ? 1 : -1;
        return `${a.props.name}`.charCodeAt(0) - `${b.props.name}`.charCodeAt(0);
    });
};
export const makeChildPath = (name, parentPath) => {
    if (!parentPath)
        return name;
    return `${parentPath}/${name}`;
};
export const stopPropagation = (event) => {
    event.stopPropagation();
    event.nativeEvent.stopImmediatePropagation();
};
export const setChildrenProps = (children, props, targetComponents = []) => {
    if (React.Children.count(children) === 0)
        return [];
    const allowAll = targetComponents.length === 0;
    const clone = (child, props = {}) => React.cloneElement(child, props);
    return React.Children.map(children, (item) => {
        if (!React.isValidElement(item))
            return item;
        if (allowAll)
            return clone(item, props);
        const isAllowed = targetComponents.find((child) => child === item.type);
        if (isAllowed)
            return clone(item, props);
        return item;
    });
};
